@@ -1,3 +1,4 @@
+import abc
 import json
 from collections import OrderedDict
 import operator
@@ -24,8 +25,11 @@ if typing.TYPE_CHECKING:
     from rasa.shared.nlu.training_data.training_data import TrainingData
 
 
-class TrainingDataReader:
-    def __init__(self):
+class TrainingDataReader(abc.ABC):
+    """Reader for NLU training data."""
+
+    def __init__(self) -> None:
+        """Creates reader instance."""
         self.filename: Text = ""
 
     def read(self, filename: Union[Text, Path], **kwargs: Any) -> "TrainingData":
@@ -33,13 +37,14 @@ class TrainingDataReader:
         self.filename = filename
         return self.reads(rasa.shared.utils.io.read_file(filename), **kwargs)
 
+    @abc.abstractmethod
     def reads(self, s: Text, **kwargs: Any) -> "TrainingData":
         """Reads TrainingData from a string."""
         raise NotImplementedError
 
 
 class TrainingDataWriter:
-    def dump(self, filename: Text, training_data) -> None:
+    def dump(self, filename: Text, training_data: "TrainingData") -> None:
         """Writes a TrainingData object in markdown format to a file."""
         s = self.dumps(training_data)
         rasa.shared.utils.io.write_text_file(s, filename)
